@@ -1157,6 +1157,7 @@ route_set_community (void *rule, struct prefix *prefix,
 	new = community_dup (rcs->com);
 
       attr->community = new;
+
       attr->flag |= ATTR_FLAG_BIT (BGP_ATTR_COMMUNITIES);
     }
 
@@ -1337,6 +1338,9 @@ route_set_ecommunity_rt (void *rule, struct prefix *prefix,
 
       bgp_info->attr->ecommunity = new_ecom;
 
+      if (old_ecom)
+	ecommunity_free (old_ecom);
+
       bgp_info->attr->flag |= ATTR_FLAG_BIT (BGP_ATTR_EXT_COMMUNITIES);
     }
   return RMAP_OKAY;
@@ -2659,7 +2663,7 @@ ALIAS (set_metric,
        "set metric <+/-metric>",
        SET_STR
        "Metric value for destination routing protocol\n"
-       "Add or subtract BGP metric\n")
+       "Add or subtract metric\n")
 
 DEFUN (no_set_metric,
        no_set_metric_cmd,
